==> ejc-sddjsorg-api-3.0.0-20211028.033407-111-sources.jar: com/ejianc/business/production/vo/ProductionTypeVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权类型
 * 
 * @author generator
 * 
 */
public class ProductionTypeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String code; // 类型编码
    private java.lang.String name; // 类型名称
    private java.lang.Long pid; // 父类型id
    private java.lang.String description; // 描述
    private String url; // 跳转路由地址
    private List<ProductionTypeVO> children;

    /**
     * 类型编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 类型编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 类型名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 类型名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 父类型id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 父类型id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }

    public List<ProductionTypeVO> getChildren() {
        return children;
    }

    public void setChildren(List<ProductionTypeVO> children) {
        this.children = children;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}

==> ejc-sddjsorg-api-3.0.0-20211103.061646-139-sources.jar: com/ejianc/business/production/vo/ProductionTypeVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权类型
 * 
 * @author generator
 * 
 */
public class ProductionTypeVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String code; // 类型编码
    private java.lang.String name; // 类型名称
    private java.lang.Long pid; // 父类型id
    private java.lang.String description; // 描述
    private String url; // 跳转路由地址
    private List<ProductionTypeVO> children;
    private Boolean canDel; // 是否可删除 true 可删 false 不可删

    public Boolean getCanDel() {
        return canDel;
    }

    public void setCanDel(Boolean canDel) {
        this.canDel = canDel;
    }

    /**
     * 类型编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 类型编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 类型名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 类型名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 父类型id
     */
    public java.lang.Long getPid() {
        return pid;
    }

    /**
     * 父类型id
     */
    public void setPid(java.lang.Long pid) {
        this.pid = pid;
    }

    public List<ProductionTypeVO> getChildren() {
        return children;
    }

    public void setChildren(List<ProductionTypeVO> children) {
        this.children = children;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}
